Skip to contents

Function to create a "tretspef + age group" table with synthetic values The table contains synthetic (randomly created) values for a selection of PODs, tretspefs, age groups and measures, across 2 "sites", as if created by 64 model runs

Usage

create_demo_sex_agegroup_tbl(seed)

Arguments

seed

integer, for reproducibility of outputs, a seed value to be used