Skip to contents

Function to create a "sex + tretspef_grouped" table with synthetic values The table contains synthetic (randomly created) values for 2 sexes, a selection of tretspef group codes, and measures, across 2 "sites", as if created by 64 model runs

Usage

create_demo_sex_tretspef_tbl(seed)

Arguments

seed

integer, for reproducibility of outputs, a seed value to be used