Skip to contents

Function to create a "step_counts" table with synthetic values The table contains synthetic (randomly created) values for a selection of 64 model runs, providing random baselines, random sizes of mitigated activity across a subset of TPMAs, and random values for demographic growth

Usage

create_demo_stepcounts_tbl(seed)

Arguments

seed

integer, for reproducibility of outputs, a seed value to be used