Function to create a "tretspef + LoS group" table with synthetic values The table contains synthetic (randomly created) values for a selection of PODs, tretspefs, LoS groups and measures, across 2 "sites", as if created by 64 model runs
create_demo_tretspef_losgroup_tbl.RdFunction to create a "tretspef + LoS group" table with synthetic values The table contains synthetic (randomly created) values for a selection of PODs, tretspefs, LoS groups and measures, across 2 "sites", as if created by 64 model runs