Function to create a "step_counts" table with synthetic values The table contains synthetic (randomly created) values for a selection of 64 model runs, providing random baselines, random sizes of mitigated activity across a subset of TPMAs, and random values for demographic growth
create_demo_stepcounts_tbl.RdFunction to create a "step_counts" table with synthetic values The table contains synthetic (randomly created) values for a selection of 64 model runs, providing random baselines, random sizes of mitigated activity across a subset of TPMAs, and random values for demographic growth