Prepare a site-level summary of main projection results
export_principal_pod_data.RdIntended to be used to create a table to be exported to .csv/.xlsx
Usage
export_principal_pod_data(
results,
pod_lookup = get_principal_pods(),
sites = NULL
)Arguments
- results
A named list containing NHP results tables
- pod_lookup
A tibble, or a function that returns a tibble, containing columns named
activity_type_label,podandpod_label. This provides friendly labels for POD variables in the data.podis the key column used for joining to data tables.- sites
Either
NULL(the default) or a vector of site codes to filter to.NULLmeans don't filter; include all sites present in the data